@@ -63,6 +63,7 @@ class Client(irc.IRCClient):
     lineRate = getattr(settings, 'RATE_LIMIT', None)
     sourceURL = 'http://github.com/shaunduncan/helga'
     encoding = 'UTF-8'
+    erroneousNickFallback = '{0}_{1}'.format(settings.NICK, int(time.time()))
 
     def __init__(self, factory=None):
         self.factory = factory
@@ -73,6 +74,25 @@ class Client(irc.IRCClient):
         # Things to keep track of
         self.channels = set()
         self.last_message = defaultdict(dict)  # Dict of x[channel][nick]
+        self.channel_loggers = {}
+
+    def get_channel_logger(self, channel):
+        """
+        Gets a logger for a channel, keeping track of ones we know about
+        """
+        if channel not in self.channel_loggers:
+            self.channel_loggers[channel] = log.get_channel_logger(channel)
+        return self.channel_loggers[channel]
+
+    def log_channel_message(self, channel, nick, message):
+        """
+        Logs one or more messages by a user on a channel using a channel
+        logger. If channel logging is not enabled, nothing happens.
+        """
+        if not settings.CHANNEL_LOGGING:
+            return
+        chan_logger = self.get_channel_logger(channel)
+        chan_logger.info(message, extra={'nick': nick})
 
     def connectionMade(self):
         logger.info('Connection made to %s', settings.SERVER['HOST'])
@@ -117,11 +137,17 @@ class Client(irc.IRCClient):
         user = self.parse_nick(user)
         message = message.strip()
 
+        # Log the incoming message and notify message subscribers
         logger.debug('[<--] %s/%s - %s', channel, user, message)
+        is_public = self.is_public_channel(channel)
 
         # When we get a priv msg, the channel is our current nick, so we need to
         # respond to the user that is talking to us
-        channel = channel if self.is_public_channel(channel) else user
+        if is_public:
+            # Only log convos on public channels
+            self.log_channel_message(channel, user, message)
+        else:
+            channel = user
 
         # Some things should go first
         try:
@@ -133,7 +159,11 @@ class Client(irc.IRCClient):
         responses = registry.process(self, channel, user, message)
 
         if responses:
-            self.msg(channel, '\n'.join(responses))
+            message = u'\n'.join(responses)
+            self.msg(channel, message)
+
+            if is_public:
+                self.log_channel_message(channel, self.nickname, message)
 
         # Update last message
         self.last_message[channel][user] = message
@@ -149,7 +179,7 @@ class Client(irc.IRCClient):
             parts = parts[:-1]
 
         stripped = '_'.join(parts)
-        self.nickname = '{0}_{1}'.format(stripped, time.time())
+        self.nickname = '{0}_{1}'.format(stripped, int(time.time()))
 
         return self.nickname
 
