@@ -2,7 +2,9 @@ import functools
 import pkg_resources
 import random
 import re
+import shlex
 import sys
+import warnings
 
 from collections import defaultdict
 from itertools import ifilter, imap
@@ -10,12 +12,30 @@ from itertools import ifilter, imap
 import smokesignal
 
 from helga import log, settings
-from helga.util.encodings import to_unicode
+from helga.util.encodings import from_unicode, to_unicode
 
 
 logger = log.getLogger(__name__)
 
 
+__all__ = [
+    'ACKS',
+    'PRIORITY_LOW',
+    'PRIORITY_NORMAL',
+    'PRIORITY_HIGH',
+    'random_ack',
+    'ResponseNotReady',
+    'Registry',
+    'registry',
+    'Plugin',
+    'Command',
+    'Match',
+    'command',
+    'match',
+    'preprocessor',
+]
+
+
 ACKS = [
     'roger',
     '10-4',
@@ -30,9 +50,13 @@ ACKS = [
 ]
 
 
-PRIORITY_LOW = 25
-PRIORITY_NORMAL = 50
-PRIORITY_HIGH = 75
+PRIORITY_LOW = settings.PLUGIN_PRIORITY_LOW
+PRIORITY_NORMAL = settings.PLUGIN_PRIORITY_NORMAL
+PRIORITY_HIGH = settings.PLUGIN_PRIORITY_HIGH
+
+
+if not settings.COMMAND_ARGS_SHLEX:
+    warnings.warn(u'Command arg parsing will default to shlex in a future version', FutureWarning)
 
 
 def random_ack():
@@ -352,11 +376,12 @@ class Command(Plugin):
     aliases = []
     help = ''
 
-    def __init__(self, command='', aliases=None, help='', priority=PRIORITY_NORMAL):
+    def __init__(self, command='', aliases=None, help='', priority=PRIORITY_NORMAL, shlex=False):
         super(Command, self).__init__(priority)
         self.command = command or self.command
         self.aliases = aliases or self.aliases
         self.help = help or self.help
+        self.shlex = shlex
 
     def parse(self, botnick, message):
         """
@@ -392,7 +417,22 @@ class Command(Plugin):
             # FIXME: Log here?
             return u'', []
 
-        return cmd, filter(bool, argstr.strip().split(' '))
+        return cmd, filter(bool, self._parse_argstr(argstr))
+
+    def _parse_argstr(self, argstr):
+        """
+        Parse an argument string for this command. If COMMAND_ARGS_SHLEX
+        is set to False, then naive whitespace splitting is performed on the argument
+        string. If not, a more robust shlex.split() is performed. For example, given
+        the message 'helga foo bar "baz qux"', the former would produce arguments
+        ['bar', '"baz', 'qux"'] while the latter would produce ['bar', 'baz qux']
+        """
+        if self.shlex or settings.COMMAND_ARGS_SHLEX:
+            argv = shlex.split(from_unicode(argstr.strip()))
+        else:
+            argv = argstr.strip().split(' ')
+
+        return map(to_unicode, argv)
 
     def run(self, client, channel, nick, message, command, args):
         """
@@ -532,7 +572,7 @@ class Match(Plugin):
         return self.run(client, channel, nick, message, matches)
 
 
-def command(command, aliases=None, help='', priority=PRIORITY_NORMAL):
+def command(command, aliases=None, help='', priority=PRIORITY_NORMAL, shlex=False):
     """
     A decorator for creating simple commands where subclassing the ``Command``
     plugin type may be overkill. This is generally the easiest way to create helga
@@ -564,8 +604,10 @@ def command(command, aliases=None, help='', priority=PRIORITY_NORMAL):
     :param help: a simple help/usage string
     :param priority: priority weight to give this plugin. Must be an integer value, a higher value
                      meaning a higher priority (default 50)
+    :param shlex: Enable using shlex.split() for arg string parsing. This will be the default
+                  behavior in a future version.
     """
-    return Command(command, aliases=aliases, help=help, priority=priority).decorate
+    return Command(command, aliases=aliases, help=help, priority=priority, shlex=shlex).decorate
 
 
 def match(pattern='', priority=PRIORITY_LOW):
